country_map = {
    'Albania': 'AL',
    "Algeria": "DZ",
    'Angola': 'AO',
    'Argentina': 'AR',
    'Austria': 'AT',
    'Australia': 'AU',
    'Azerbaijan': 'AZ',
    'Barbados': 'BB',
    'Bangladesh': 'BD',
    'Bulgaria': 'BG',
    'Bahrain': 'BH',
    'Brunei': 'BN',
    'Bolivia': 'BO',
    'Brazil': 'BR',
    'Belarus': 'BY',
    'Canada': 'CA',
    'Congo, dem. Rep.': 'CD',
    'Congo, Republic of.': 'CG',
    'Chile': 'CL',
    'Cameroon': 'CM',
    'China': 'CN',
    'Colombia': 'CO',
    'Cuba': 'CU',
    'Czech Republic': 'CZ',
    'Germany': 'DE',
    'Denmark': 'DK',
    'Algeria': 'DZ',
    'Ecuador': 'EC',
    'Estonia': 'EE',
    'Egypt': 'EG',
    'Spain': 'ES',
    'France': 'FR',
    'Gabon': 'GA',
    'United Kingdom': 'GB',
    'Ghana': 'GH',
    'Equatorial Guinea': 'GQ',
    'Greece': 'GR',
    'Guatemala': 'GT',
    'Guyana': 'GY',
    'Croatia': 'HR',
    'Hungary': 'HU',
    'Indonesia': 'ID',
    'India': 'IN',
    'Iraq': 'IQ',
    'Iran': 'IR',
    'Italy': 'IT',
    'Jordan': 'JO',
    'Japan': 'JP',
    'Kenya': 'KE',
    'Kyrgyzstan': 'KG',
    'Cambodia': 'KH',
    'Kuwait': 'KW',
    'Kazakhstan': 'KZ',
    'Lithuania': 'LT',
    'Libya': 'LY',
    'Morocco': 'MA',
    'Madagascar': 'MG',
    'Myanmar': 'MM',
    'Mauritania': 'MR',
    'Mexico': 'MX',
    'Malaysia': 'MY',
    'Niger': 'NE',
    'Nigeria': 'NG',
    'Netherlands': 'NL',
    'Norway': 'NO',
    'Neutral Zone': None,
    'United Arab Emirates': 'AE',
    'New Zealand': 'NZ',
    'Oman': 'OM',
    'Peru': 'PE',
    'Papua New Guinea': 'PG',
    'Philippines': 'PH',
    'Pakistan': 'PK',
    'Poland': 'PL',
    'Qatar': 'QA',
    'Romania': 'RO',
    'Serbia': 'RS',
    'Russia': 'RU',
    'Saudi Arabia': 'SA',
    'Sudan': 'SD',
    'Suriname': 'SR',
    'Syria': 'SY',
    'Chad': 'TD',
    'Thailand': 'TH',
    'Tajikistan': 'TJ',
    'East Timor': 'TL',
    'Turkmenistan': 'TM',
    'Tunisia': 'TN',
    'Turkey': 'TR',
    'Trinidad & Tobago': 'TT',
    'Taiwan': 'TW',
    'Ukraine': 'UA',
    'USA': 'US',
    'United States': 'US',
    'Georgia': 'GE',
    'Uzbekistan': 'UZ',
    'Venezuela': 'VE',
    'Vietnam': 'VN',
    'Yemen': 'YE',
    'South Africa': 'ZA',

}
